@@ -1,5 +1,4 @@
-from onnx2kerastl import customonnxlayer
+from onnx2kerastl import customonnxlayer  # type: ignore
 
 # expose customonnxlayer to the outside
 customonnxlayer = customonnxlayer
-
