@@ -3,7 +3,7 @@ from collections import defaultdict
 from pathlib import Path
 from typing import Set, Dict, Any, List, Type, Optional
 import tensorflow as tf  # type: ignore
-from tensorflow.python.keras.utils.generic_utils import func_load
+from tensorflow.python.keras.utils.generic_utils import func_load  # type: ignore
 
 from leap_model_parser.contract.importmodelresponse import NodeResponse, WrapperData
 
